==> xlniuxdata-vipgame-1.0.39-20151203.044132-10-sources.jar: com/xunlei/niux/data/vipgame/vo/MultimediaTips.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


@Table(tableName="multimedia_tips",pkFieldName="seqid",pkFieldAssign=false)
public class MultimediaTips {
	private Long seqid;
    private String title;
    private String displayPage;
    private Integer initDisplay;
    private String gamesIndexPage;
    private String startTime;
    private String endTime;
    private String jumpToUrl;
    private String sucai;
    private String neirong;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
    @Column(columnName="title",isWhereColumn=true,operator= Operator.LIKE)
    private String likeTitle;

    public String getLikeTitle() {
        return likeTitle;
    }

    public void setLikeTitle(String likeTitle) {
        this.likeTitle = likeTitle;
    }

    public String getDisplayPage() {
        return displayPage;
    }

    public void setDisplayPage(String displayPage) {
        this.displayPage = displayPage;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getGamesIndexPage() {
        return gamesIndexPage;
    }

    public void setGamesIndexPage(String gamesIndexPage) {
        this.gamesIndexPage = gamesIndexPage;
    }

    public Integer getInitDisplay() {
        return initDisplay;
    }

    public void setInitDisplay(Integer initDisplay) {
        this.initDisplay = initDisplay;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getJumpToUrl() {
        return jumpToUrl;
    }

    public void setJumpToUrl(String jumpToUrl) {
        this.jumpToUrl = jumpToUrl;
    }

    public String getNeirong() {
        return neirong;
    }

    public void setNeirong(String neirong) {
        this.neirong = neirong;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getSucai() {
        return sucai;
    }

    public void setSucai(String sucai) {
        this.sucai = sucai;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }
}

==> xlniuxdata-vipgame-1.0.65-20160701.094904-9-sources.jar: com/xunlei/niux/data/vipgame/vo/MultimediaTips.java <==
package com.xunlei.niux.data.vipgame.vo;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;


@Table(tableName="multimedia_tips",pkFieldName="seqid",pkFieldAssign=false)
public class MultimediaTips {
	private Long seqid;
    private String title;
    private String displayPage;
    private Integer initDisplay;
    private String gamesIndexPage;
    private String startTime;
    private String endTime;
    private String jumpToUrl;
    private String sucai;
    private String neirong;
	private String inputBy;
	private String inputTime;
	private String editBy;
	private String editTime;
    @Column(columnName="title",isWhereColumn=true,operator= Operator.LIKE)
    private String likeTitle;
    private Integer msgType;
    private Long forUidGroupId;

    public Long getForUidGroupId() {
        return forUidGroupId;
    }

    public void setForUidGroupId(Long forUidGroupId) {
        this.forUidGroupId = forUidGroupId;
    }

    public Integer getMsgType() {
        return msgType;
    }

    public void setMsgType(Integer msgType) {
        this.msgType = msgType;
    }

    public String getLikeTitle() {
        return likeTitle;
    }

    public void setLikeTitle(String likeTitle) {
        this.likeTitle = likeTitle;
    }

    public String getDisplayPage() {
        return displayPage;
    }

    public void setDisplayPage(String displayPage) {
        this.displayPage = displayPage;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public String getGamesIndexPage() {
        return gamesIndexPage;
    }

    public void setGamesIndexPage(String gamesIndexPage) {
        this.gamesIndexPage = gamesIndexPage;
    }

    public Integer getInitDisplay() {
        return initDisplay;
    }

    public void setInitDisplay(Integer initDisplay) {
        this.initDisplay = initDisplay;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getJumpToUrl() {
        return jumpToUrl;
    }

    public void setJumpToUrl(String jumpToUrl) {
        this.jumpToUrl = jumpToUrl;
    }

    public String getNeirong() {
        return neirong;
    }

    public void setNeirong(String neirong) {
        this.neirong = neirong;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getStartTime() {
        return startTime;
    }

    public void setStartTime(String startTime) {
        this.startTime = startTime;
    }

    public String getSucai() {
        return sucai;
    }

    public void setSucai(String sucai) {
        this.sucai = sucai;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }
}
